/*** ヘッダー ***/
body .l-header {
  font-family: "Noto Sans JP", "Yu Gothic", "游ゴシック", YuGothic, "游ゴシック体", "ヒラギノ角ゴ Pro W3", "メイリオ", sans-serif;
  color: #000;
  letter-spacing: normal;
  max-height: none;
  box-shadow:none;
}

.l-header a {
  color: #000;
}

.l-header__logo img {
  width: 451px;
}

.l-header__global > li:nth-child(1){
  display: block;
}

@media screen and (min-width: 1025px) and (max-width: 1139px) {
  .l-header__logo img {
      width: 300px;
  }
}

@media screen and (min-width: 1025px){
  .l-header a {
      font-weight: 500;
  }
  .l-header__global__bottom{
      display: none;
  }

}

@media screen and (max-width: 1024px){
  .l-header a {
      color: #000;
      font-weight: 400;
  }
  .l-header__global__bottom{
      margin: 15px 0 15px;
      padding: 0;
      display: block;
      font-size: 1.3rem;
  }

  .l-header__global__bottom li{
      border-bottom: 1px solid #d9d9d6;
  }
  .l-header__global__bottom li a{
      color: #777777;
      display: flex;
      align-items: center;
      height: 40px;
      padding-left: 25px;
  }
  
  .l-header__logo img {
      width: 306px;
  }
}

/*** フッター ***/

body .l-site-footer{
  font-family: "Noto Sans JP", "Yu Gothic", "游ゴシック", YuGothic, "游ゴシック体", "ヒラギノ角ゴ Pro W3", "メイリオ", sans-serif;
  color: #000;
  letter-spacing: normal;
  text-align: start;
}

body .l-footer{
  font-family: "Noto Sans JP", "Yu Gothic", "游ゴシック", YuGothic, "游ゴシック体", "ヒラギノ角ゴ Pro W3", "メイリオ", sans-serif;
  letter-spacing: normal;
  text-align: start;
}

  
.l-site-footer__logo {
  margin: 0 0 45px;
}

.l-site-footer_top {
  display: flex;
  justify-content: flex-start;
  flex-wrap: wrap;
  gap: 12px 30px;
  border-bottom: 1px solid #7d7d7d;
  padding: 0 0 22px;
  font-weight: bold;
}



.l-site-footer_bottom {
  display: flex;
  justify-content: flex-start;
  gap: 30px;
  padding: 22px 0 75px;
  font-weight: bold;
}

.l-footer-contacts__container {
  justify-content: flex-start;
  grid-gap: 30px;
  gap: 30px;
}

.l-footer-contacts__contact a img {
  width: auto;
}
@media screen and (min-width: 768px) {
  .l-site-footer_top a{
      font-weight: bold;
  }
  
  .l-site-footer_bottom a{
      font-weight: bold;
  }
}


@media screen and (max-width: 767px) {
  .l-site-footer_bottom {
      font-size: 1.4rem;
      font-weight: 500;
      flex-direction: column;
      flex-wrap: wrap;
      grid-gap: 10px 0;
      gap: 10px 0;
      min-width: 0;
      border-bottom: 1px solid #7d7d7d;
      padding: 30px 0;
      margin-bottom: 50px;
      color: #24292d;
  }

  .l-site-footer_top {
      font-size: 1.4rem;
      font-weight: 500;
      flex-direction: column;
      flex-wrap: wrap;
      grid-gap: 10px 0;
      gap: 10px 0;
      min-width: 0;
      padding: 0 0 30px;
      color: #24292d;
  }
  .l-site-footer_top a{
      font-weight: 500;
  }
  
  .l-site-footer_bottom a{
      font-weight: 500;
  }
}

.l-footer-contacts img {
  width: auto;
}

/*** PPTSMKT共通CSS打消し ***/

.l-inner {
  font-family: "Noto Sans JP", "Yu Gothic", "游ゴシック", YuGothic, "游ゴシック体", "ヒラギノ角ゴ Pro W3", "メイリオ", sans-serif;
}


@media screen and (max-width: 767px) {
  html body {
      font-size: 1.6rem;
      line-height: 1.7;
  }
}

@media screen and (min-width: 768px),
print {
  html body {
      font-size: 1.6rem;
      line-height: 1.7;
  }
}

.l-inner .m-post-navigation {
  color: #000;
}

.l-inner .m-post-navigation a {
  color: #000;
}

.c-sns-share {
  color: #000;
}

.l-content .m-post-navigation a {
  color: #000;
}

.m-relation {
  color: #000;
}

.m-relation a {
  color: #000;
}

.m-breadcrumbs__items {
  flex-wrap: wrap;
  gap: 2px 0;
}


/* 共通スタイル打消し */


main .c-firstview{
  margin-top: 0;
  z-index: 0;
}

.c-heading01{
  display: block;
  font-size: 1.5em;
  font-weight: bold;
}
.l-article-page:has(.c-firstview){
  padding-top: 0;
}


@media print, screen and (min-width: 1025px) {

  .wrapper:has(.c-firstview){
    margin-top: 0;
  }
}

.m-service-search #agenda{
  display: none;
}

.m-service-search__tab li p:after {
  display: none;
}

.m-service-search__tab-diplayNo{
  display: none;
}

.m-service-other-diplayNo{
    display: none;
}




